package Task::Kensho::All;

use strict;
use warnings;

our $VERSION = '0.39';

1;

=head1 NAME

Task::Kensho::All - Install all of Task::Kensho

=head1 SYNOPSIS

  cpanm Task::Kensho::All

=head1 DESCRIPTION

Installs every sub-task of L<Task::Kensho|Task::Kensho/"DESCRIPTION">, a list
of modules recommended by the
L<Enlightened Perl Organisation|https://www.enlightenedperl.org>. Don't use
this unless you really want everything.

=head1 BUGS

Report any issues on the public bugtracker.

=head1 AUTHOR

Dan Book <dbook@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Dan Book.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=head1 SEE ALSO

L<Task::Kensho>
